@@ -20,9 +20,9 @@
 #define KGAMERENDERER_H
 
 class QGraphicsView;
-#include <QtCore/QHash>
-#include <QtCore/QObject>
-#include <QtGui/QPixmap>
+#include <QHash>
+#include <QObject>
+#include <QPixmap>
 
 #include <libkdegames_export.h>
 
@@ -115,11 +115,12 @@ class KDEGAMES_EXPORT KGameRenderer : public QObject
 		Q_DECLARE_FLAGS(Strategies, Strategy)
 
 		///Constructs a new KGameRenderer that renders @a prov->currentTheme().
-		///@param cacheSize the cache size in megabytes (if not given, a sane
+		///@param prov the theme provider
+                ///@param cacheSize the cache size in megabytes (if not given, a sane
 		///default is used)
 		///@warning This constructor may only be called from the main thread.
 		explicit KGameRenderer(KgThemeProvider* prov, unsigned cacheSize = 0);
-		///@overload that allows to use KGameRenderer without a theme provider
+		///overload that allows to use KGameRenderer without a theme provider
 		///          (useful when there is only one theme)
 		///@note Takes ownership of @a theme.
 		explicit KGameRenderer(KgTheme* theme, unsigned cacheSize = 0);
@@ -164,7 +165,7 @@ class KDEGAMES_EXPORT KGameRenderer : public QObject
 		Strategies strategies() const;
 		///Enables/disables an optimization strategy for this renderer. By
 		///default, both the UseDiskCache and the UseRenderingThreads strategies
-		///are enabled. This is a sane default for 99% of all games. You might 
+		///are enabled. This is a sane default for 99% of all games. You might
 		///only want to disable optimizations if the graphics are so simple that
 		///the optimizations create an overhead in your special case.
 		///
