@@ -18,4 +18,10 @@
 
 //This file is needed because the <KgSound> header needs to link to
 //"../kgaudioscene.h" instead of "../audio/kgaudioscene.h".
+
+#ifndef LIBKDEGAMEG_KGAUDIOSCENE_H
+#define LIBKDEGAMEG_KGAUDIOSCENE_H
+
 #include "audio/kgaudioscene.h"
+
+#endif
